@@ -3,7 +3,7 @@ package RPerl::DataStructure::Array::ListElements;
 use strict;
 use warnings;
 use RPerl::AfterSubclass;
-our $VERSION = 0.003_000;
+our $VERSION = 0.004_000;
 
 # [[[ OO INHERITANCE ]]]
 use parent qw(RPerl::GrammarRule);
@@ -166,4 +166,88 @@ sub ast_to_cpp__generate__CPPOPS_CPPTYPES {
     return $cpp_source_group;
 }
 
+sub ast_to_cpp__generate__CPPOPS_CPPTYPES__bson_build {
+    { my string_hashref::method $RETURN_TYPE };
+    ( my object $self, my string_hashref $modes) = @ARG;
+    my string_hashref $cpp_source_group = { CPP => q{} };
+
+#    RPerl::diag( 'in Array::ListElements->ast_to_cpp__generate__CPPOPS_CPPTYPES__bson_build(), received $self = ' . "\n" . RPerl::Parser::rperl_ast__dump($self) . "\n" );
+#    RPerl::diag( 'in Array::ListElements->ast_to_cpp__generate__CPPOPS_CPPTYPES__bson_build(), have $modes->{_inside_print_operator} = ' . $modes->{_inside_print_operator} . "\n" );
+
+    if ( ( ref $self ) ne 'ListElements_210' ) {
+        die RPerl::Parser::rperl_rule__replace(
+            'ERROR ECOGEASCP00, CODE GENERATOR, ABSTRACT SYNTAX TO C++: Grammar rule ' . ( ref $self ) . ' found where ListElements_210 expected, dying' )
+            . "\n";
+    }
+
+    # save to stack of saved flags, when needed
+    if ( ( exists $modes->{_inside_list_elements} ) and ( defined $modes->{_inside_list_elements} ) ) {
+        if ( ( not exists $modes->{_inside_list_elements_saved} ) or ( not defined $modes->{_inside_list_elements_saved} ) ) {
+            $modes->{_inside_list_elements_saved} = [];
+        }
+        push @{ $modes->{_inside_list_elements_saved} }, $modes->{_inside_list_elements};
+    }
+    $modes->{_inside_list_elements} = 1;
+
+    my object $list_element0      = $self->{children}->[0];
+    my object $list_elements_star = $self->{children}->[1];
+
+    # DEV NOTE: list element value may need to call ..._bson_build() generator
+    my string_hashref $cpp_source_subgroup;
+    if ($list_element0->can('ast_to_cpp__generate__CPPOPS_CPPTYPES__bson_build')) {
+        $cpp_source_subgroup = $list_element0->ast_to_cpp__generate__CPPOPS_CPPTYPES__bson_build($modes);
+    }
+    else {
+        $cpp_source_subgroup = $list_element0->ast_to_cpp__generate__CPPOPS_CPPTYPES($modes);
+    }
+    RPerl::Generator::source_group_append( $cpp_source_group, $cpp_source_subgroup );
+
+    foreach my object $list_element ( @{ $list_elements_star->{children} } ) {
+
+#        RPerl::diag( 'in Array::ListElements->ast_to_cpp__generate__CPPOPS_CPPTYPES__bson_build(), top of foreach() loop, have $list_element = ' . "\n" . RPerl::Parser::rperl_ast__dump($list_element) . "\n" );
+        if ( ref $list_element eq 'TERMINAL' ) {
+            if ( $list_element->{attr} ne q{,} ) {
+                die RPerl::Parser::rperl_rule__replace( q{ERROR ECOGEASRP00, CODE GENERATOR, ABSTRACT SYNTAX TO RPERL: Grammar rule '}
+                        . $list_element->{attr}
+                        . q{' found where OP21_LIST_COMMA ',' expected, dying} )
+                    . "\n";
+            }
+
+            # OP21_LIST_COMMA
+            if ( ( exists $modes->{_inside_print_operator} ) and ( defined $modes->{_inside_print_operator} ) and $modes->{_inside_print_operator} ) {    # or
+
+#                ((exists $modes->{_inside_die_operator}) and (defined $modes->{_inside_die_operator}) and $modes->{_inside_die_operator})) { # DEV NOTE, CORRELATION #rp102b
+# replace comma with << when inside print operator
+                $cpp_source_group->{CPP} .= ' << ';
+            }
+            else {
+                # keep comma when not inside print operator
+#                $cpp_source_group->{CPP} .= $list_element->{attr} . q{ };
+                $cpp_source_group->{CPP} .= ' << ';
+            }
+        }
+        else {
+            # DEV NOTE: list element value may need to call ..._bson_build() generator
+            if ($list_element->can('ast_to_cpp__generate__CPPOPS_CPPTYPES__bson_build')) {
+                $cpp_source_subgroup = $list_element->ast_to_cpp__generate__CPPOPS_CPPTYPES__bson_build($modes);
+            }
+            else {
+                $cpp_source_subgroup = $list_element->ast_to_cpp__generate__CPPOPS_CPPTYPES($modes);
+            }
+            RPerl::Generator::source_group_append( $cpp_source_group, $cpp_source_subgroup );
+        }
+    }
+
+    # restore from stack of saved flags, when needed
+    delete $modes->{_inside_list_elements};
+    if (    ( exists $modes->{_inside_list_elements_saved} )
+        and ( defined $modes->{_inside_list_elements_saved} )
+        and ( scalar $modes->{_inside_list_elements_saved} ) )
+    {
+        $modes->{_inside_list_elements} = pop @{ $modes->{_inside_list_elements_saved} };
+        if ( not scalar $modes->{_inside_list_elements_saved} ) { delete $modes->{_inside_list_elements_saved}; }
+    }
+    return $cpp_source_group;
+}
+
 1;    # end of class
