@@ -16,9 +16,10 @@ our $VERSION = 0.001_000;
 
 # [[[ OPERATIONS ]]]
 
-our integer $foo = sub {
+sub foo {
+    { my integer $RETURN_TYPE };
     ( my string $bar, my integer $bat, my integer $baz ) = @ARG;
     print $bar, "\n";
     return $bat + $baz;
-};
+}
 foo('howdy!', 23, 42)
