@@ -13,8 +13,6 @@ our $VERSION = 0.001_000;
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ SUBROUTINES ]]]
-our number $empty_sub = sub {
-    return 0._2;
-};
+sub empty_sub { { my number $RETURN_TYPE }; return 0._2; }
 
 1;    # end of package
