@@ -15,9 +15,8 @@ our $VERSION = 0.001_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ SUBROUTINES ]]]
-our number $foo = sub {
-    return - 234_567.890_12;
-};
+sub foo { { my number $RETURN_TYPE }; return - 234_567.890_12; }
 
 # [[[ OPERATIONS ]]]
-foo();
\ No newline at end of file
+foo();
+
