@@ -10,7 +10,7 @@ our $VERSION = 0.001_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ SUBROUTINES ]]]
-our integer $foo = sub { return (((2))); };
+sub foo { { my integer $RETURN_TYPE }; return (((2))); }
 
 # [[[ OPERATIONS ]]]
 foo();
