@@ -15,10 +15,11 @@ our $VERSION = 0.001_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ SUBROUTINES ]]]
-our integer_arrayref $foo = sub {
+sub foo {
+    { my integer_arrayref $RETURN_TYPE };
 # DEV NOTE: DO NOT RUN PERLTIDY ON THIS FILE!  the line below should read 'return(...' not 'return (...'
     return( ( ( %{ { a => 2 } } ) ) );
-};
+}
 
 # [[[ OPERATIONS ]]]
 foo();
