@@ -17,9 +17,7 @@ use RPerl::Test;
 our hashref $properties
     = { empty_property => my integer $TYPED_empty_property = 2 ;
 
-# [[[ OO METHODS & SUBROUTINES ]]]
-our void::method $empty_method = sub {
-    return 2;
-};
+# [[[ SUBROUTINES & OO METHODS ]]]
+sub empty_method { { my void::method $RETURN_TYPE }; return 2; }
 
 1;                  # end of class
