@@ -16,7 +16,7 @@ our $VERSION = 0.001_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ SUBROUTINES ]]]
-our integer $foo_single = sub { return 23; };
+sub foo_single { { my integer $RETURN_TYPE }; return 23; }
 
 # [[[ OPERATIONS ]]]
 my integer $retval = foo_single();
