@@ -17,13 +17,15 @@ our $VERSION = 0.001_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ SUBROUTINES ]]]
-our void $foo_args = sub {
+sub foo_args {
+    { my void $RETURN_TYPE };
     # PERLTIDY BUG, failure to put a space between $arg3 and closing )
 #    (my integer $arg1, my number $arg2, my string $arg3) = @ARG;
     ( my integer $arg1, my number $arg2, my string $arg3 ) = @ARG;
     print 'have $arg1 * $arg2 = ', number_to_string($arg1 * $arg2), "\n";
     print 'have $arg3 x $arg1 = ', ($arg3 x $arg1), "\n";
-};
+    return;
+}
 
 # [[[ OPERATIONS ]]]
 foo_args(5, 2.575, 'over and ');
