@@ -15,7 +15,7 @@ our $VERSION = 0.000_001;
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ INCLUDES ]]]
-use RPerl::Test::TypeCheckingTrace::AllTypes;
+use RPerl::Test::TypeCheckingTrace::AllTypes qw(check_integer);
 
 # [[[ OPERATIONS ]]]
 check_integer( { a => 0, b => 1, c => 2 } );
